permission.logics package
=========================

Submodules
----------

permission.logics.author module
-------------------------------

.. automodule:: permission.logics.author
    :members:
    :undoc-members:
    :show-inheritance:

permission.logics.base module
-----------------------------

.. automodule:: permission.logics.base
    :members:
    :undoc-members:
    :show-inheritance:

permission.logics.collaborators module
--------------------------------------

.. automodule:: permission.logics.collaborators
    :members:
    :undoc-members:
    :show-inheritance:

permission.logics.groupin module
--------------------------------

.. automodule:: permission.logics.groupin
    :members:
    :undoc-members:
    :show-inheritance:

permission.logics.staff module
------------------------------

.. automodule:: permission.logics.staff
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: permission.logics
    :members:
    :undoc-members:
    :show-inheritance:
